==> otobo-10.0.1.tar.gz: otobo-10.0.1/README.md <==
What is OTOBO?
===================================
OTOBO is one of the most flexible web-based ticketing
systems used for Customer Service, Help Desk, IT Service Management
based on the ((OTRS)) Community Edition.
With a fast implementation and easy customization to your needs it
helps you reducing costs and increasing the efficiency and transparency
of your business communication. OTOBO offers always full [**OTOBO**](https://www.otobo.de) functionality.

You can find a list of features here
[OTOBO Homepage](https://otobo.de/de/otobo-features/).


License
=======
It is distributed under the GNU General Public License - see the
accompanying [COPYING](COPYING) file for more details.


Documentation
=============
You can find documentation [online](https://doc.otobo.de/). The source code of OTOBO and its public extension
modules is available on [github](https://github.com/RotherOSS).


Professional Services for OTOBO
==============================

Whether you need help in configuring or customizing OTOBO or you want to be on the safe side,
don't hesitate to contact us: We offer a wide range of professional services such as
world-wide enterprise support, consulting and engineering including process design,
implementation, customization, application support, and fully managed service.

We offer best professional support from the Rother OSS OTOBO team, reliable OTOBO security and regular free updates.

The [Rother OSS GmbH](https://www.otobo.de/) offers specific [training programs](https://otobo.de/de/angebot/beratung-schulung/) in
different countries. You can either participate in one of our public OTOBO Administrator training seminars which take
place regularly, or benefit from an inhouse training seminar that covers all the specific needs of your company.

Software requirements
=====================
The software and hardware requirements [can be found in our documentation.](https://doc.otobo.org/manual/installation/stable/en/content/requirements.html)

==> otobo-10.0.3.tar.gz: otobo-10.0.3/README.md <==
What is OTOBO?
===================================
OTOBO is one of the most flexible web-based ticketing
systems used for Customer Service, Help Desk, IT Service Management
based on the ((OTRS)) Community Edition.
With a fast implementation and easy customization to your needs it
helps you reducing costs and increasing the efficiency and transparency
of your business communication. OTOBO offers always full [**OTOBO**](https://www.otobo.de) functionality.

You can find a list of features here
[OTOBO Homepage](https://otobo.de/de/otobo-features/).


License
=======
It is distributed under the GNU General Public License - see the
accompanying [COPYING](COPYING) file for more details.


Documentation
=============
You can find documentation [online](https://doc.otobo.org/). The source code of OTOBO and its public extension
modules is available on [github](https://github.com/RotherOSS).


Professional Services for OTOBO
==============================

Whether you need help in configuring or customizing OTOBO or you want to be on the safe side,
don't hesitate to contact us: We offer a wide range of professional services such as
world-wide enterprise support, consulting and engineering including process design,
implementation, customization, application support, and fully managed service.

We offer best professional support from the Rother OSS OTOBO team, reliable OTOBO security and regular free updates.

The [Rother OSS GmbH](https://www.otobo.de/) offers specific [training programs](https://otobo.de/de/angebot/beratung-schulung/) in
different countries. You can either participate in one of our public OTOBO Administrator training seminars which take
place regularly, or benefit from an inhouse training seminar that covers all the specific needs of your company.

Software requirements
=====================
The software and hardware requirements [can be found in our documentation.](https://doc.otobo.org/manual/installation/stable/en/content/requirements.html)
